@@ -1,8 +1,11 @@
+# "penfit" object to store the result of a penalized regression
+# Theseobjects are meant to be accessed by the user, but not made directly by the user
 setClass("penfit", 
   representation(
     penalized = "vector", 
     unpenalized = "vector",
     residuals = "vector",
+    fitted = "vector",
     loglik = "numeric",
     penalty = "vector",
     iterations = "numeric",
@@ -14,6 +17,7 @@ setClass("penfit",
   )
 )
 
+# creation method for a penfit object 
 .makepenfit <- function(object, unpenalized, model, lambda1, lambda2, orthogonalizer) {
   out <- new("penfit")
   
@@ -24,6 +28,7 @@ setClass("penfit",
   out@penalized <- beta
   
   out@residuals <- object$fit$residuals
+  out@fitted <- object$fit$fitted
   
   out@loglik <- if (is.na(object$fit$loglik)) -Inf else object$fit$loglik
   out@penalty <- object$penalty
@@ -34,10 +39,7 @@ setClass("penfit",
   
   out@model <- model
   
-  if (model == "cox") 
-    out@nuisance <- list(baseline = object$fit$baseline())
-  if (model == "linear")
-    out@nuisance <- list(sigma2 = object$fit$sigma2)
+  out@nuisance <- object$fit$nuisance
   
   out@lambda1 <- lambda1
   out@lambda2 <- lambda2
@@ -45,13 +47,13 @@ setClass("penfit",
   out
 }
 
-
+# show method
 setMethod("show", "penfit", function(object) {
   cat("Penalized", object@model, "regression object\n")
   if (object@converged) {
     coefs <- unlist(c(object@penalized, object@unpenalized))
     cat(length(coefs), "regression coefficients")
-    if (all(object@lambda1>0)) cat(" of which", sum(coefs != 0), "are non-zero")
+    if (any(object@lambda1>0) || any(object@lambda2 == Inf)) cat(" of which", sum(coefs != 0), "are non-zero")
     cat("\n\n")
     cat("Loglikelihood =\t", object@loglik, "\n")
     if (any(object@lambda1 > 0))
@@ -69,6 +71,7 @@ setMethod("show", "penfit", function(object) {
   }
 })
 
+# extracts the coefficients
 setMethod("coefficients", "penfit", function(object, which = c("nonzero", "all", "penalized", "unpenalized")) {
   which <- match.arg(which)
   switch(which, 
@@ -78,10 +81,18 @@ setMethod("coefficients", "penfit", function(object, which = c("nonzero", "all",
     nonzero = c(object@unpenalized, object@penalized[object@penalized != 0]))
 })
 
+# extracts the residuals
 setMethod("residuals", "penfit", function(object, ...) {
   object@residuals
 })
 
+# extracts the fitted values
+setMethod("fitted.values", "penfit", function(object, ...) {
+  object@fitted
+})
+
+
+# extracts the baseline hazard (survival models only)
 setGeneric("basehaz")
 setMethod("basehaz", "penfit", function(fit, centered) {
   if (fit@model == "cox") 
@@ -90,12 +101,14 @@ setMethod("basehaz", "penfit", function(fit, centered) {
     return(NULL)
 })
 
+# extracts the penalty
 setGeneric("penalty", function(object, ...) standardGeneric("penalty"))
 setMethod("penalty", "penfit", function(object, ...) {
   object@penalty
 })
 
+# extracts the likelihood
 setGeneric("loglik", function(object, ...) standardGeneric("loglik"))
 setMethod("loglik", "penfit", function(object, ...) {
   object@loglik
-})
\ No newline at end of file
+})
